@@ -1,17 +1,29 @@
 from context import signalboxclient
 # import client
+import datetime
 import uuid
 import numpy as np
 import environment
 
-creds = signalboxclient.client.Credentials(environment.api_key)
-test_client = signalboxclient.client.SignalBoxClient(creds)
-my_token = test_client.access_token
+# creds = signalboxclient.client.Credentials(environment.api_key)
+# test_client = signalboxclient.client.SignalBoxClient(creds)
+# my_token = test_client.access_token
+
+# dev env
+api_key='NWZkODIzN2QtMjZmZS00MTliLTkzYzUtZmI1OGI1MjczOGZl'
+host='app73204e59.azurewebsites.net'
+port=443
+test_client = signalboxclient.client.SignalBoxClient(signalboxclient.client.Credentials(api_key), signalboxclient.client.Configuration(host, port))
 
 # create user
 user_id = str(uuid.uuid1())
-test_client.create_user('testuser', user_id)
+u = test_client.create_user('testuser', user_id)
 print('created user with id=', user_id)
+# update the user
+u['properties'] = {
+    'client_test.py': datetime.datetime.now().strftime('%Y-%m-%dT%H:%M:%S.%f%z')
+}
+test_client.create_or_update_users([u])
 offer = test_client.create_offer('my_offer', 'AUD', 100, 50)
 offer_id = offer['id']
 
@@ -48,7 +60,7 @@ experiment_id = experiment['id']
 # list all experiments
 experiments_first_page = test_client.query_experiments(1)
 print('len experiments_first_page =', len(experiments_first_page.items))
-assert experiments_first_page.pagination.totalItemCount > 1
+assert experiments_first_page.pagination.totalItemCount > 0
 
 get_experiment_response = test_client.get_experiment(experiment_id)
 print('\nPrinting get_experiment test response: ', get_experiment_response)
